var NAVTREEINDEX2 =
{
"group__API__Data__Interfaces.html#ae002548f6392819ff90d72f64898dca6":[5,9,1,11],
"group__API__Data__Interfaces.html#ae039cff4622424d30f99811665f4de4f":[5,9,10,6],
"group__API__Data__Interfaces.html#ae04050a90bd86fe5b8462b62aaa9547e":[5,9,0,16],
"group__API__Data__Interfaces.html#ae1d888af673475dbcf85104b6c359a6e":[5,9,0,12],
"group__API__Data__Interfaces.html#ae2a9b938ace8afeb6de759dadb7181a5":[5,9,4,0],
"group__API__Data__Interfaces.html#ae2bd3e92fba4412cabef91740fa6d30f":[5,9,4,9],
"group__API__Data__Interfaces.html#ae739aa4a6e1eee69f1fcf144443c98d9":[5,9,3,5],
"group__API__Data__Interfaces.html#aeaaaed6dbef4bfc013c133654c1825fc":[5,9,10,0],
"group__API__Data__Interfaces.html#aeb80d9cbbad4df7188003cd514355413":[5,9,9,5],
"group__API__Data__Interfaces.html#aeb8ae0434284030f7c898374eedb5034":[5,9,8,3],
"group__API__Data__Interfaces.html#aeb90c3cc8a1b0c9226935cddff6f1a65":[5,9,9,6],
"group__API__Data__Interfaces.html#aec58c5c35ca45b0e88aae4711396f587":[5,9,5,8],
"group__API__Data__Interfaces.html#aedf1d1402f554bf6e9e6db7f72ad6fb6":[5,9,0,4],
"group__API__Data__Interfaces.html#af00bd371238ac5b99036775525ac4543":[5,9,2,4],
"group__API__Data__Interfaces.html#af0499fdbb48df14c8630d2b45520cdad":[5,9,10,3],
"group__API__Data__Interfaces.html#af214b15f13ea9a8b103182b2ec55d844":[5,9,6,0],
"group__API__Data__Interfaces.html#af34733fda32ba11e6a2ec1569d39fc3e":[5,9,1,4],
"group__API__Data__Interfaces.html#af4cf7dcbcb99e697561312b2b7c44ffa":[5,9,4,4],
"group__API__Data__Interfaces.html#af8b89ca3cd7bbd01dec98a8087ea1d9c":[5,9,5,10],
"group__API__Data__Interfaces.html#af9bc59bf8aa5132dcfeaf2c48713b5e1":[5,9,3,4],
"group__API__Data__Interfaces.html#afa68754d79d58848e3ec781903bdb1a9":[5,9,5,4],
"group__API__Data__Interfaces.html#afb8adfbac498be2eb6a587460f161e73":[5,9,1,2],
"group__API__Data__Interfaces.html#afc1c0d3f8d08869ddf5fdda82ef2ac5c":[5,9,0,19],
"group__API__Data__Interfaces.html#afd365e7e0abc01f07b6d7b9201c4ce22":[5,9,1,10],
"group__API__Data__Interfaces.html#ga001c8954d20044b466c661cf7c9f9fe0":[5,9,28],
"group__API__Data__Interfaces.html#ga0022c371e342ac366720c7735f4be3be":[5,9,95],
"group__API__Data__Interfaces.html#ga011705e0a88798562f7afb2753a6b1ce":[5,9,112],
"group__API__Data__Interfaces.html#ga01603469c939a499779b3c1d2e5fd533":[5,9,171],
"group__API__Data__Interfaces.html#ga02005aa2a3c838802d95d0426a937d8d":[5,9,138],
"group__API__Data__Interfaces.html#ga057157e8f437d111d74b7167386f9e9a":[5,9,169],
"group__API__Data__Interfaces.html#ga07eb2ecc8ee04523993aeb0be19a8878":[5,9,52],
"group__API__Data__Interfaces.html#ga088d9e8e6e18e77ed13c299e836c3aeb":[5,9,184],
"group__API__Data__Interfaces.html#ga08bed7d1e9b7cb2b2b76932eb9c33353":[5,9,186],
"group__API__Data__Interfaces.html#ga0b6869745c464525b25a0757d112c318":[5,9,105],
"group__API__Data__Interfaces.html#ga0cea5d347fdd4b5a44ecc9fe0295898c":[5,9,59],
"group__API__Data__Interfaces.html#ga11d470bd48328eb4432e1c546ea22618":[5,9,175],
"group__API__Data__Interfaces.html#ga12139db59366898a24b596bdaddb2d92":[5,9,164],
"group__API__Data__Interfaces.html#ga18ffdda48c748445b090a7c54702f4c1":[5,9,44],
"group__API__Data__Interfaces.html#ga1bb9b86971544ea19a9d29ff5da7a1b0":[5,9,97],
"group__API__Data__Interfaces.html#ga1be29ee257e3d9c3321df759b8105cb1":[5,9,111],
"group__API__Data__Interfaces.html#ga1d0a0dc4903585e099b2e4b16a22946a":[5,9,110],
"group__API__Data__Interfaces.html#ga1db61ac4eddfff7f4b97002815c7ecfa":[5,9,180],
"group__API__Data__Interfaces.html#ga1e92dc5d143be583708d87498d2dc9cb":[5,9,30],
"group__API__Data__Interfaces.html#ga2019a063133420e320552ec0c57cf42e":[5,9,69],
"group__API__Data__Interfaces.html#ga21ae3f41a59615f892f196b8cab16ee4":[5,9,83],
"group__API__Data__Interfaces.html#ga22a8126d41b43e71c3c79e210401b12e":[5,9,146],
"group__API__Data__Interfaces.html#ga23fc48b94f9766bf8eac580512b8b7cf":[5,9,132],
"group__API__Data__Interfaces.html#ga24575d92ad85dd6707815de2d8341ca8":[5,9,45],
"group__API__Data__Interfaces.html#ga25ebd6929cd9216225cf4bc37398af6e":[5,9,61],
"group__API__Data__Interfaces.html#ga28e9d620c4dc360cdbb0437e81d66543":[5,9,96],
"group__API__Data__Interfaces.html#ga2af8405c3f0fff62ea7269fc279cab55":[5,9,140],
"group__API__Data__Interfaces.html#ga2b6d7d5240ddebdfcf11c40e00dba969":[5,9,57],
"group__API__Data__Interfaces.html#ga2cab8f7f6a3f484e16241c41239664fa":[5,9,90],
"group__API__Data__Interfaces.html#ga2e654441cd023fb3824392b7a0d3cb21":[5,9,124],
"group__API__Data__Interfaces.html#ga2e7a3317c103dde219b75dbf922951d4":[5,9,116],
"group__API__Data__Interfaces.html#ga2f010739c3833ff77eda44585a0a4794":[5,9,125],
"group__API__Data__Interfaces.html#ga30da5dedded6584f211cb41d6811bd2e":[5,9,203],
"group__API__Data__Interfaces.html#ga31019da41b566cc4cb36564c69138124":[5,9,51],
"group__API__Data__Interfaces.html#ga335bad7c45aa5df70227ce11f03edc0f":[5,9,36],
"group__API__Data__Interfaces.html#ga341ae5d71140a231be9dfab9d65dd116":[5,9,145],
"group__API__Data__Interfaces.html#ga359c851b4a4b0adb9685ade2f78818d9":[5,9,213],
"group__API__Data__Interfaces.html#ga35be6cc12e0655d2770c96e6faac572a":[5,9,56],
"group__API__Data__Interfaces.html#ga37f8a43c38418b3d1354c32c559e6596":[5,9,174],
"group__API__Data__Interfaces.html#ga3a3cf303a3e3be144aab7abdf587c900":[5,9,66],
"group__API__Data__Interfaces.html#ga3aa3b2a467688f95fe6dd3355112dfc6":[5,9,188],
"group__API__Data__Interfaces.html#ga3bb8d6c4169e578b219849148eece329":[5,9,43],
"group__API__Data__Interfaces.html#ga3ef8a3c5b91f3d3b048a4e5f51a4c4c0":[5,9,47],
"group__API__Data__Interfaces.html#ga3f0c5626c9d5f7addb417834d6be7861":[5,9,48],
"group__API__Data__Interfaces.html#ga40384636cdeec2bdeeccf5a50a081c3b":[5,9,170],
"group__API__Data__Interfaces.html#ga40f2d8762bc1060e939eecae75f9be08":[5,9,198],
"group__API__Data__Interfaces.html#ga40f5b44c5d9bfd39f2f305aa32a25787":[5,9,212],
"group__API__Data__Interfaces.html#ga4248716bc322e1628b86365d7b9a8822":[5,9,183],
"group__API__Data__Interfaces.html#ga451ea6b212d0442b2bda2937c08968f5":[5,9,94],
"group__API__Data__Interfaces.html#ga461a1d65e0f4559dacbc1ba77eafbb2b":[5,9,147],
"group__API__Data__Interfaces.html#ga47cea6fc5b88aaa359066e8192fafe95":[5,9,162],
"group__API__Data__Interfaces.html#ga487b41c917f6317221d85ab626afd353":[5,9,130],
"group__API__Data__Interfaces.html#ga4a52c2c736f00d5694fd12f94468d161":[5,9,60],
"group__API__Data__Interfaces.html#ga4d59be187bd3b97b656ab0e049f50fb2":[5,9,120],
"group__API__Data__Interfaces.html#ga4f137b139435d4cddcd15704fe46cbbd":[5,9,199],
"group__API__Data__Interfaces.html#ga4fecd59ebb415d8e64749ab6d0e41870":[5,9,46],
"group__API__Data__Interfaces.html#ga53b17bba653978ee769ec4a2a3bdae68":[5,9,133],
"group__API__Data__Interfaces.html#ga540f980b1c4bee16c78d84097a8b07f9":[5,9,193],
"group__API__Data__Interfaces.html#ga54dca826f319369d94c4cd6be0eb4828":[5,9,208],
"group__API__Data__Interfaces.html#ga550d6222ff484201dbd3d39bb7baeb7d":[5,9,33],
"group__API__Data__Interfaces.html#ga567d2e3780dabc30269af5e54fe20660":[5,9,78],
"group__API__Data__Interfaces.html#ga56d6ae5fe9283bfb77e13f07c2513184":[5,9,24],
"group__API__Data__Interfaces.html#ga588a7cbb105708b588e5fe008fbb9e9c":[5,9,91],
"group__API__Data__Interfaces.html#ga59929ae2575a893d320f356c4f893453":[5,9,126],
"group__API__Data__Interfaces.html#ga59cbe4cadbe314b73807dc20363db5b9":[5,9,93],
"group__API__Data__Interfaces.html#ga5c4dfa96a4ffa7be08e22a9dc20484e4":[5,9,149],
"group__API__Data__Interfaces.html#ga5ebc1643dba047e9a628cf190df03169":[5,9,134],
"group__API__Data__Interfaces.html#ga6062186a44105e3024a62d2077a32ffe":[5,9,165],
"group__API__Data__Interfaces.html#ga61d4cba212074e157a4236f9e03ffce9":[5,9,54],
"group__API__Data__Interfaces.html#ga63c26124d04338849795d76f291a3739":[5,9,100],
"group__API__Data__Interfaces.html#ga64e03caa2ee034b7e86320a21fcf82ee":[5,9,58],
"group__API__Data__Interfaces.html#ga66106513707ed71b8849b1c1bbb3df75":[5,9,196],
"group__API__Data__Interfaces.html#ga66508648e621019be00d86832d66f278":[5,9,160],
"group__API__Data__Interfaces.html#ga66b9bd15585432fa97499d37aaf13351":[5,9,79],
"group__API__Data__Interfaces.html#ga66df9aff4ea14be546df745f17365568":[5,9,161],
"group__API__Data__Interfaces.html#ga6711060d6f12245db58b245912e92005":[5,9,176],
"group__API__Data__Interfaces.html#ga69dd5090534b513a374089627254f73c":[5,9,81],
"group__API__Data__Interfaces.html#ga6d0c09ee7cd90ac23454ef2040a4bc25":[5,9,211],
"group__API__Data__Interfaces.html#ga6f28e1a774923108005760426cf8da5b":[5,9,18],
"group__API__Data__Interfaces.html#ga6f64340041ca2277f071aebd9bd3ea7b":[5,9,21],
"group__API__Data__Interfaces.html#ga71795d4368a064e25c1366a168429529":[5,9,131],
"group__API__Data__Interfaces.html#ga720fcf673578ec23e583b5f674626847":[5,9,148],
"group__API__Data__Interfaces.html#ga72c9db50152ed5bf9f18ad3a355c5376":[5,9,197],
"group__API__Data__Interfaces.html#ga748def68db84b3cb9da305b0e3f7c935":[5,9,71],
"group__API__Data__Interfaces.html#ga75d457d6e5181fff12d031d2a2c6db28":[5,9,167],
"group__API__Data__Interfaces.html#ga78a31ef2148b8439a2c0e897d9179b84":[5,9,201],
"group__API__Data__Interfaces.html#ga7af8e4f90b557fefaa09f40a930efd74":[5,9,128],
"group__API__Data__Interfaces.html#ga7b1f8a896527eb5d667b3e6ccf0ce7bb":[5,9,88],
"group__API__Data__Interfaces.html#ga7c5c5fe50717bae757862f58053f97a5":[5,9,67],
"group__API__Data__Interfaces.html#ga7cc322b2f03830ec7afbb58b7416a283":[5,9,65],
"group__API__Data__Interfaces.html#ga7d44b8a0594932a8cece13e1cc9932bb":[5,9,72],
"group__API__Data__Interfaces.html#ga7e3ef9efbc7a65adad27f9ac27493493":[5,9,139],
"group__API__Data__Interfaces.html#ga7ea069447f11e836d7b709c97d90b570":[5,9,108],
"group__API__Data__Interfaces.html#ga81160c064d381e20cf874ec053e167f9":[5,9,166],
"group__API__Data__Interfaces.html#ga81b34820b1a410d218ad08528c0317f6":[5,9,157],
"group__API__Data__Interfaces.html#ga821cbbf32e68e9af90dcbeb81b9c7034":[5,9,104],
"group__API__Data__Interfaces.html#ga82eea89e2f23a9fdc1f34c03db68a97b":[5,9,86],
"group__API__Data__Interfaces.html#ga833b734aa76cdee89245cb0710793cf9":[5,9,144],
"group__API__Data__Interfaces.html#ga83ba12ab43444d61f4966dc76aa160d6":[5,9,85],
"group__API__Data__Interfaces.html#ga84a3cc04ef603ab17af6d14f23c6ca00":[5,9,109],
"group__API__Data__Interfaces.html#ga8599a8f318fcadbafcc55f9c568678f1":[5,9,156],
"group__API__Data__Interfaces.html#ga86956bce305447697cb9346bee692b24":[5,9,214],
"group__API__Data__Interfaces.html#ga86b64dc68625997cf3c0bb9eae3ee68a":[5,9,75],
"group__API__Data__Interfaces.html#ga87725438ebaccd40d8b1b90e17b46247":[5,9,39],
"group__API__Data__Interfaces.html#ga88d8275866e6f3f430d01e5909cc17f7":[5,9,168],
"group__API__Data__Interfaces.html#ga8a4c1ddb71e09437717e298c3e2c39f9":[5,9,204],
"group__API__Data__Interfaces.html#ga8aa19dcac39f053949c1bb1b4f5fad1d":[5,9,155],
"group__API__Data__Interfaces.html#ga8c04948b40dc3902e9b3de7a84383381":[5,9,206],
"group__API__Data__Interfaces.html#ga8c40de57e43f28beac889b34d0bc69e4":[5,9,55],
"group__API__Data__Interfaces.html#ga8fa1c7e18fa7c621ec68fc5aa32ef181":[5,9,64],
"group__API__Data__Interfaces.html#ga9037815eabc726906d66140b62c03b9b":[5,9,50],
"group__API__Data__Interfaces.html#ga91461bface98435f7e90d515c4aa04cb":[5,9,23],
"group__API__Data__Interfaces.html#ga9263fae0971cb00a9f9108a4a4b1e285":[5,9,49],
"group__API__Data__Interfaces.html#ga9294121fe81a39b6b5e74e8e66bac3e0":[5,9,153],
"group__API__Data__Interfaces.html#ga95f3f5141265f8a78f8b5802be7ea20c":[5,9,22],
"group__API__Data__Interfaces.html#ga9719eab3a5e9fbaad2837b4a985a3a14":[5,9,106],
"group__API__Data__Interfaces.html#ga97859bcb7bc60911362087eefc9249ed":[5,9,209],
"group__API__Data__Interfaces.html#ga97c7b78c97576eb44741bdd7e2183fa7":[5,9,121],
"group__API__Data__Interfaces.html#ga988036ae1f9385832c2988064a4f27af":[5,9,192],
"group__API__Data__Interfaces.html#ga9d14e3576605217f1a160a710fad8178":[5,9,152],
"group__API__Data__Interfaces.html#ga9dc1bbf7a41070a6fcf82e728cae1542":[5,9,77],
"group__API__Data__Interfaces.html#ga9f6457e4a7e558101dd6ad64076a6a99":[5,9,150],
"group__API__Data__Interfaces.html#gaa093608060a222a89fff01130e9c5c64":[5,9,154],
"group__API__Data__Interfaces.html#gaa15cff8f1148e572348095ac5a2ab421":[5,9,32],
"group__API__Data__Interfaces.html#gaa1d6124d3f84336020897d1df1b1cc50":[5,9,163],
"group__API__Data__Interfaces.html#gaa23416a6d049b276fe57b19e069b68b3":[5,9,62],
"group__API__Data__Interfaces.html#gaa29d5f4bd11fce82cd9a01b0e860bf75":[5,9,216],
"group__API__Data__Interfaces.html#gaa2f2140147f15e7b9eec1443690e357c":[5,9,107],
"group__API__Data__Interfaces.html#gaa35025b4b6126c3f22232cea8915cdad":[5,9,68],
"group__API__Data__Interfaces.html#gaa46eb27abc7439c03776d68062f029d4":[5,9,84],
"group__API__Data__Interfaces.html#gaa7a81bad81376cc0f7b8162a4d8dbacd":[5,9,135],
"group__API__Data__Interfaces.html#gaac406e853e677b31a57f2d54263d2602":[5,9,53],
"group__API__Data__Interfaces.html#gaadbd0557a0ca2178a2ebf7673319f53c":[5,9,92],
"group__API__Data__Interfaces.html#gaaeff5c191edc5f3df8ba1a319acd0af9":[5,9,35],
"group__API__Data__Interfaces.html#gab1c57c537a980a2de5e595b2f6204772":[5,9,27],
"group__API__Data__Interfaces.html#gab2bf7713cad5570775bdf4efec79502d":[5,9,136],
"group__API__Data__Interfaces.html#gab316b2febb2b5fb92e83bbaab780f046":[5,9,40],
"group__API__Data__Interfaces.html#gab328b8e0b234147ebe36ceb8e7a55b0a":[5,9,202],
"group__API__Data__Interfaces.html#gab517790a521d1434d9f52de97091f493":[5,9,177],
"group__API__Data__Interfaces.html#gab5666e2f9f46e4aebe367983347384de":[5,9,98],
"group__API__Data__Interfaces.html#gab59c3b606776bdc54f6ccf3f1db4bf38":[5,9,205],
"group__API__Data__Interfaces.html#gab6e12b04b231773f2eff496f57d29ee8":[5,9,114],
"group__API__Data__Interfaces.html#gab7746e58c367202ad0bc8a2decb1bed8":[5,9,178],
"group__API__Data__Interfaces.html#gab7b07d0d2a253e02e1b2d2260cc3fa94":[5,9,76],
"group__API__Data__Interfaces.html#gab7f9484602aeef560cc2e5904e3b2cff":[5,9,194],
"group__API__Data__Interfaces.html#gab9110ecfa66b148e770a375566c1c19d":[5,9,74],
"group__API__Data__Interfaces.html#gab915146b6d59fbd8e6d04480511f7945":[5,9,17],
"group__API__Data__Interfaces.html#gab91cbc596a65e6a4322b657c79934269":[5,9,137],
"group__API__Data__Interfaces.html#gabb03b0b367f445b692e37ab3237d877f":[5,9,195],
"group__API__Data__Interfaces.html#gabcce7df711e56cafddfd82f8f5ee794b":[5,9,113],
"group__API__Data__Interfaces.html#gabe33df9aebbeab34a9f4f319bff5d3e2":[5,9,142],
"group__API__Data__Interfaces.html#gac046f5fb0472cada47cd44650194b1c8":[5,9,14],
"group__API__Data__Interfaces.html#gac14cfc52c450c81dd4789a7aace79d3b":[5,9,122],
"group__API__Data__Interfaces.html#gac23356ed31839f1d1c52efccb7a99dd7":[5,9,15],
"group__API__Data__Interfaces.html#gac2fe5221c0ccc0d082e5bc65830e497b":[5,9,41],
"group__API__Data__Interfaces.html#gac5fd11be8dd93ebfbbf344623f3c2014":[5,9,123],
"group__API__Data__Interfaces.html#gac739182a43ec4dd00618d783b1f2a16c":[5,9,26],
"group__API__Data__Interfaces.html#gac778227f8ff624d7f7ea04f1407fcb92":[5,9,143],
"group__API__Data__Interfaces.html#gac77fef789ec34682ba00b38dcc501170":[5,9,31],
"group__API__Data__Interfaces.html#gac7b7e5f3d4d9a1468df3b9b92743a9fd":[5,9,158],
"group__API__Data__Interfaces.html#gacb816db830d6991909a35a8c0e93a843":[5,9,185],
"group__API__Data__Interfaces.html#gacc62f1150a403bb550d3538b2bffea17":[5,9,119],
"group__API__Data__Interfaces.html#gacc7903845cb442f141de2b1d9450fc63":[5,9,179],
"group__API__Data__Interfaces.html#gacd706856652f629563bce3c0bb528ec6":[5,9,182],
"group__API__Data__Interfaces.html#gacd95c31b537322b1d4000a1248b9c425":[5,9,187],
"group__API__Data__Interfaces.html#gacd9e0b5bd06d1b7d88be4e0143be8a68":[5,9,13],
"group__API__Data__Interfaces.html#gacee0a9e166f87b48da1f56e1ae5d988d":[5,9,189],
"group__API__Data__Interfaces.html#gad3c08c06e55e86993fa5cb77dce95095":[5,9,101],
"group__API__Data__Interfaces.html#gad4850366b77ead9f60c6f7e1d1064b22":[5,9,89],
"group__API__Data__Interfaces.html#gad51f09163a11aad56f942ee152b28d13":[5,9,129],
"group__API__Data__Interfaces.html#gad5ffed03f141096fca4e1e2583c84e22":[5,9,200],
"group__API__Data__Interfaces.html#gad6ca41b04e0265671d4bf899dd433c1e":[5,9,115],
"group__API__Data__Interfaces.html#gad7e204d690945cbe5145bc8950078291":[5,9,117],
"group__API__Data__Interfaces.html#gad9407e7339eb6c8e32e598b7c4c85d70":[5,9,20],
"group__API__Data__Interfaces.html#gad99e209fafc3ad5e0c4da0de02e5bda2":[5,9,70],
"group__API__Data__Interfaces.html#gada534736df809f642437792b1acd7af8":[5,9,172],
"group__API__Data__Interfaces.html#gadccf196d01dd9c43e931827a86f886b2":[5,9,63],
"group__API__Data__Interfaces.html#gadcf7063b1cd8d0feed7054e6e4d9d217":[5,9,210],
"group__API__Data__Interfaces.html#gaddd9b273ddf82a320f66946228f12103":[5,9,173],
"group__API__Data__Interfaces.html#gade238eb388cbb34bf9a93643bfa4df83":[5,9,25],
"group__API__Data__Interfaces.html#gadf8eac3f96b6e63911f23165141411df":[5,9,29],
"group__API__Data__Interfaces.html#gae2a4195d99eedac191857c43cd454226":[5,9,141],
"group__API__Data__Interfaces.html#gae3d95a1379358cbd85c663c8462da98c":[5,9,16],
"group__API__Data__Interfaces.html#gae48e867d81c554b199b127cf9bd4f5b2":[5,9,207],
"group__API__Data__Interfaces.html#gae5d1dbf657ce2c4f55bce1ac2f982d6a":[5,9,118],
"group__API__Data__Interfaces.html#gae95b657d947e611060590d506d8e15dc":[5,9,34],
"group__API__Data__Interfaces.html#gaea999f5e67e778ac28c0a8bc1633ff28":[5,9,87],
"group__API__Data__Interfaces.html#gaeb6356075b3f57e8c7aeccc85f076d87":[5,9,103],
"group__API__Data__Interfaces.html#gaebeefdd9980c18575924ed9860315bcf":[5,9,151],
"group__API__Data__Interfaces.html#gaec6ca64cc2c52e319b9b73cc4f753658":[5,9,217],
"group__API__Data__Interfaces.html#gaeeb3ff0360cafe3fc54e16da2d002c5b":[5,9,82],
"group__API__Data__Interfaces.html#gaeed0ab452c0906a650097368bd1c6ba3":[5,9,80],
"group__API__Data__Interfaces.html#gaef6039a7976d3ee6c6916df28a08da1a":[5,9,19],
"group__API__Data__Interfaces.html#gaefbbb2e643662ee4d7c816d91e8e14df":[5,9,99],
"group__API__Data__Interfaces.html#gaf011a057a557a66271ce06e8109c11c4":[5,9,73],
"group__API__Data__Interfaces.html#gaf0937aae4bedeb03e9ebbec36cc1dad6":[5,9,102],
"group__API__Data__Interfaces.html#gaf0fa0d2dc99ab880ccfe12061770dad2":[5,9,38],
"group__API__Data__Interfaces.html#gaf1843d7f93510e6bf53da173eb9dd75e":[5,9,159],
"group__API__Data__Interfaces.html#gaf3bd64a64625f45859f596db3bb9b40a":[5,9,42],
"group__API__Data__Interfaces.html#gaf5938ea67a4a2c4f140ec527698bf850":[5,9,181],
"group__API__Data__Interfaces.html#gaf5ea640f2c977e3ae95a6be9b3be3bee":[5,9,127],
"group__API__Data__Interfaces.html#gaf972d52af628f82488eeea311eadb4f6":[5,9,191],
"group__API__Data__Interfaces.html#gafb92c2538dc629d823221c5dc16bd767":[5,9,190],
"group__API__Data__Interfaces.html#gafd439524218c70b6b4a784fb12824c28":[5,9,215],
"group__API__Data__Interfaces.html#gafd9d133c4d658b777d9800eba79765b3":[5,9,37],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca1020cba73248160933d8f6c901293437":[5,9,107,5],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca264b360136a55f91ae62c48faa02f376":[5,9,107,1],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca40a80154bc81a5eb4eea06771010bba3":[5,9,107,6],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca4c3642251b2ddf957338ef2729de7f5f":[5,9,107,3],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca5a50ee28bfd93b68341e7644f3e810aa":[5,9,107,4],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca65cfc4ac63a449dd5da3c40ae63bb949":[5,9,107,0],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca7b3ec1ca579bfc82a35d282ed69b0300":[5,9,107,10],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca80d5bec40d12c9b05e1331bab739e39f":[5,9,107,9],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357caa0881ef4be5491fcfb7df81b9778a247":[5,9,107,12],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357caa45ce766ad2fe7020e82e462390c7b38":[5,9,107,8],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357cab24c1ea83c1e376895d316a0981bee0c":[5,9,107,7],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357cac55e5bac53f8121d107f4bebf2d26155":[5,9,107,11],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357cacb8ea4adb7ed650338bfe9e69d3e1bb2":[5,9,107,2],
"group__API__Data__Interfaces.html#structstarpu__bcsr__interface":[5,9,10],
"group__API__Data__Interfaces.html#structstarpu__block__interface":[5,9,4],
"group__API__Data__Interfaces.html#structstarpu__coo__interface":[5,9,3],
"group__API__Data__Interfaces.html#structstarpu__csr__interface":[5,9,9],
"group__API__Data__Interfaces.html#structstarpu__data__copy__methods":[5,9,0],
"group__API__Data__Interfaces.html#structstarpu__data__interface__ops":[5,9,1],
"group__API__Data__Interfaces.html#structstarpu__matrix__interface":[5,9,2],
"group__API__Data__Interfaces.html#structstarpu__multiformat__data__interface__ops":[5,9,11]
};
